
#ifndef UNION_EXPORT_H
#define UNION_EXPORT_H

#ifdef UNION_STATIC_DEFINE
#  define UNION_EXPORT
#  define UNION_NO_EXPORT
#else
#  ifndef UNION_EXPORT
#    ifdef Union_EXPORTS
        /* We are building this library */
#      define UNION_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define UNION_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef UNION_NO_EXPORT
#    define UNION_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef UNION_DECL_DEPRECATED
#  define UNION_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef UNION_DECL_DEPRECATED_EXPORT
#  define UNION_DECL_DEPRECATED_EXPORT UNION_EXPORT UNION_DECL_DEPRECATED
#endif

#ifndef UNION_DECL_DEPRECATED_NO_EXPORT
#  define UNION_DECL_DEPRECATED_NO_EXPORT UNION_NO_EXPORT UNION_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef UNION_NO_DEPRECATED
#    define UNION_NO_DEPRECATED
#  endif
#endif

#define UNION_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(UNION_NO_DEPRECATED) && !defined(UNION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define UNION_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define UNION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(UNION_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define UNION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(UNION_NO_DEPRECATED_WARNINGS) && !defined(UNION_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define UNION_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define UNION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(UNION_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define UNION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(UNION_NO_DEPRECATED)
#  undef UNION_DEPRECATED
#  define UNION_DEPRECATED_EXPORT UNION_EXPORT
#  define UNION_DEPRECATED_NO_EXPORT UNION_NO_EXPORT
#elif defined(UNION_NO_DEPRECATED_WARNINGS)
#  define UNION_DEPRECATED
#  define UNION_DEPRECATED_EXPORT UNION_EXPORT
#  define UNION_DEPRECATED_NO_EXPORT UNION_NO_EXPORT
#else
#  define UNION_DEPRECATED UNION_DECL_DEPRECATED
#  define UNION_DEPRECATED_EXPORT UNION_DECL_DEPRECATED_EXPORT
#  define UNION_DEPRECATED_NO_EXPORT UNION_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define UNION_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define UNION_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef UNION_NO_DEPRECATED
#  define UNION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60704
#endif
#ifdef UNION_NO_DEPRECATED_WARNINGS
#  define UNION_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef UNION_DEPRECATED_WARNINGS_SINCE
#  ifdef UNION_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define UNION_DEPRECATED_WARNINGS_SINCE UNION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define UNION_DEPRECATED_WARNINGS_SINCE 0x60704
#  endif
#endif

#ifndef UNION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define UNION_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef UNION_DEPRECATED
#  define UNION_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > UNION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define UNION_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* UNION_EXPORT_H */
